@@ -1,19 +1,19 @@
 # Copyright (C) 2003-2004, 2010 by the gtk2-perl team (see the file AUTHORS for
 # the full list)
-# 
+#
 # This library is free software; you can redistribute it and/or modify it under
 # the terms of the GNU Library General Public License as published by the Free
 # Software Foundation; either version 2.1 of the License, or (at your option)
 # any later version.
-# 
+#
 # This library is distributed in the hope that it will be useful, but WITHOUT
 # ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 # FOR A PARTICULAR PURPOSE.  See the GNU Library General Public License for
 # more details.
-# 
+#
 # You should have received a copy of the GNU Library General Public License
 # along with this library; if not, write to the Free Software Foundation, Inc.,
-# 59 Temple Place - Suite 330, Boston, MA  02111-1307  USA.
+# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
 # $Id$
 #
@@ -223,16 +223,18 @@ do that.  Especially watch out for other classes in your ISA tree.
 *new = \&Glib::Object::new;
 
 sub import {
+   shift;  # $self
+
    # we seem to be imported by classes using classes which use us.
    # ignore anything that doesn't look like a registration attempt.
-   return unless @_ > 1;
+   return unless @_;
 
-   my ($self, $superclass, %arg) = @_;
+   my $superclass = shift;
    my $class = caller;
 
    Glib::Type->register_object(
       $superclass, $class,
-      %arg,
+      @_,
    );
 
    # ensure that we have a perlish new().  the old version of this
